"""Main module."""

import dateutil.parser
import datetime

LOAD_ZONES = ["LZ_HOUSTON", "LZ_WEST", "LZ_NORTH", "LZ_SOUTH"]

GETNOW_API_URL = "https://app.gogriddy.com/api/v1/insights/getnow"
DEFAULT_REQUEST_TIMEOUT = 15


class GriddyPriceData:
    """Griddy price data."""

    def __init__(self, data):
        self._now = GriddyPricePoint(data["now"])
        self._forecast = []
        for price_point in data["forecast"]:
            self._forecast.append(GriddyPricePoint(price_point))

    @property
    def now(self):
        return self._now

    @property
    def forecast(self):
        return self._forecast


class GriddyPricePoint:
    """Object that represents griddy price data for a specific date time."""

    def __init__(self, data):
        self._price_ckwh = data["price_ckwh"]
        self._price_type = data["price_type"]
        self._datetime = as_utc_from_local(dateutil.parser.parse(data["date"]))

    @property
    def datetime(self):
        return self._datetime

    @property
    def price_cents_kwh(self):
        return self._price_ckwh

    @property
    def price_type(self):
        return self._price_type


class AsyncGriddy:
    """Async griddy api."""

    def __init__(
        self, websession, timeout=DEFAULT_REQUEST_TIMEOUT, settlement_point=None,
    ):
        """Create griddy async api object."""
        self._websession = websession
        self._settlement_point = settlement_point
        self._timeout = timeout

    async def async_getnow(self):
        """Call api to get the current price."""
        response = await self._websession.request(
            "post",
            GETNOW_API_URL,
            timeout=self._timeout,
            json={"settlement_point": self._settlement_point},
        )
        return GriddyPriceData(await response.json())


def as_utc_from_local(dtime):
    """Converts the datetime returned from an activity to UTC."""
    return dtime.astimezone(tz=datetime.timezone.utc)



#!/usr/bin/env python

"""Tests for `griddypower` package."""

import datetime
import os
import aiounittest

from aiohttp import ClientError, ClientSession
from aioresponses import aioresponses

from griddypower.async_api import GETNOW_API_URL, AsyncGriddy, LOAD_ZONES


def load_fixture(filename):
    """Load a fixture."""
    path = os.path.join(os.path.dirname(__file__), "fixtures", filename)
    with open(path) as fptr:
        return fptr.read()


class TestApiAsync(aiounittest.AsyncTestCase):
    @aioresponses()
    async def test_async_getnow(self, aiomock):
        """Test for parsing getnow into objects."""
        aiomock.post(GETNOW_API_URL, body=load_fixture("getnow.json"))

        griddy = AsyncGriddy(ClientSession(), settlement_point=LOAD_ZONES[0])
        data = await griddy.async_getnow()
        assert data.now.price_cents_kwh == "1.26900000000000000000"
        assert data.now.price_type == "lmp"
        assert data.now.datetime == datetime.datetime(
            2020, 3, 8, 18, 10, 16, tzinfo=datetime.timezone.utc
        )

        assert data.forecast[0].price_cents_kwh == "1.32000000"
        assert data.forecast[0].price_type == "dam"
        assert data.forecast[0].datetime == datetime.datetime(
            2020, 3, 8, 19, 0, tzinfo=datetime.timezone.utc
        )



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = ["aiohttp", "python-dateutil"]

setup_requirements = [
    "pytest-runner",
]

test_requirements = [
    "pytest>=3",
    "aiounittest",
    "aioresponses",
]

setup(
    author="J. Nick Koston",
    author_email="nick@koston.org",
    python_requires=">=3.5",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Python API for Griddy Wholesale Electricity",
    install_requires=requirements,
    license="BSD license",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="griddypower",
    name="griddypower",
    packages=find_packages(include=["griddypower", "griddypower.*"]),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/bdraco/griddypower",
    version="0.1.0",
    zip_safe=False,
)
